<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                xmlns:raw="http://www.destatis.de/schema/datml-raw/2.0/de"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:d="http://www.destatis.de/schema/datml-raw/2.0/de"
                version="2.0">
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <xsl:output method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <xsl:template match="/">
      <xsl:variable name="berichtszeitraum"
                    as="xs:string?"
                    select="d:DatML-RAW-D/d:nachricht/d:berichtszeitraum/concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
      <xsl:if test="not(matches($berichtszeitraum, '^\d\d\d\d-\d\d$'))">
         <xsl:message terminate="yes">In der Nachricht konnte kein Berichtszeitraum erkannt werden. Prüfung wurde abgebrochen.</xsl:message>
      </xsl:if>
      <xsl:choose>
         <xsl:when test="'2018-05' le $berichtszeitraum">
            <xsl:apply-templates select="/" mode="M_00041840059999000001"/>
         </xsl:when>
         <xsl:when test="'2017-05' le $berichtszeitraum">
            <xsl:apply-templates select="/" mode="M_00041740059999000001"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:message terminate="yes">Für den Berichtszeitraum <xsl:value-of select="$berichtszeitraum"/> liegen keine Validierungsregeln vor. Prüfung wurde abgebrochen.</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template xmlns:sdf="http://www.destatis.de/schema/datml-sdf/2.0"
                 xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001schematron-select-full-path"
                 match="*">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="local-name()"/>
         <xsl:choose>
            <xsl:when test="local-name()='satz' and d:mm[@name='UUID']/d:wert">
               <xsl:text>[mm[@name='UUID' and wert='</xsl:text>
               <xsl:value-of select="d:mm[@name='UUID']/d:wert"/>
               <xsl:text>']]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='satz'">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="position()"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='mmgr' or local-name()='mm'">
               <xsl:text>[@name='</xsl:text>
               <xsl:value-of select="@name"/>
               <xsl:text>']</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[name(.) = name(current())] or       following-sibling::*[name(.) = name(current())]">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="count(preceding-sibling::*[name(.) = name(current())]) + 1"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
         </xsl:choose>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="/"/>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="text()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.text-', 1 + count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="comment()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.comment-', 1 + count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="processing-instruction()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.processing-instruction-', 1 + count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="@*">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="*"
                 priority="-0.5">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.', name(), '-', 1 + count(preceding-sibling::*[name() = name(current())]), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="/">U</xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="*"
                 priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="node()">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="@*">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(), ':', '.')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001"
                 match="text()"
                 priority="-1"/>
   <xsl:template mode="M_00041840059999000001" match="/">
      <rep:pruefprotokoll xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll">
         <xsl:sequence select="/d:DatML-RAW-D/(d:optionen|d:protokoll|d:absender|d:empfaenger)"/>
         <svrl:schematron-output title="GWA-Schematron-Validierer für XGewerbeanzeige (Version 1.3)"
                                 schemaVersion="00041840059999000001">
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_APPL</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Anwendbarkeit der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M2" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_HMM</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Erforderliche und zulässige Hilfsmerkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M3" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMDEF</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmale der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M4" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMGRDEF</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmalsgruppen der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M5" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMTYPE</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Datentypen der Merkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M6" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_OCCURS</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Häufigkeiten und Bedingungen</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M7" select="/"/>
         </svrl:schematron-output>
      </rep:pruefprotokoll>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2"
                 match="d:nachricht/d:erhebung"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:kennung[@klasse = 'ERHID'] = '0004'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:kennung[@klasse = 'ERHID'] = '0004'">
               <xsl:attribute name="id">XGWA_APPL_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Element d:kennung muss vorhanden sein und den Wert 0004 haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2"
                 match="d:nachricht/d:berichtszeitraum"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2018-05'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2018-05'">
               <xsl:attribute name="id">XGWA_APPL_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Der Berichtszeitraum der Nachricht (<xsl:text/>
                  <xsl:value-of select="concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
                  <xsl:text/>) darf nicht vor der Wirksamkeit dieser Lieferbeschreibung liegen (ausgenommen Testlieferungen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M2" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3" match="d:nachricht" priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1">
               <xsl:attribute name="id">XGWA_HMM_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitIDZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'GemeindeName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'GemeindeName']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'Bemerkungen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'Bemerkungen']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Bemerkungen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1">
               <xsl:attribute name="id">XGWA_HMM_001_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerEmpfaenger: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3"
                 match="d:nachricht/d:hmm"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')">
               <xsl:attribute name="id">XGWA_HMM_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Hilfsmerkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M3" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M4" match="d:mm" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'Doktorgrad', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'GbRGesellschafter', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NameFirmaGewerbetreibender', 'NameOrganisation', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'Doktorgrad', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'GbRGesellschafter', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NameFirmaGewerbetreibender', 'NameOrganisation', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_MMDEF_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmal definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M4" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M4" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M5" match="d:mmgr" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'Autor', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson', 'WeitereNeuAusgeuebteTaetigkeiten', 'WeitereTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'Autor', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson', 'WeitereNeuAusgeuebteTaetigkeiten', 'WeitereTaetigkeiten')">
               <xsl:attribute name="id">XGWA_MMGRDEF_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmalsgruppe definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M5" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M5" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltAm', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'DatumMeldung', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'GueltigAb')]/d:wert"
                 priority="1054">
      <xsl:variable name="day" select="substring(., 1, 2)"/>
      <xsl:variable name="month" select="substring(., 3, 2)"/>
      <xsl:variable name="year" select="substring(., 5, 4)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^\d{8}$') and $date castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^\d{8}$') and $date castable as xs:date">
               <xsl:attribute name="id">XGWA_MMTYPE_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein gültiges Datum (<xsl:text/>
                  <xsl:value-of select="$date"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonPLZ', 'Begriff', 'EintragungPLZ', 'FaxVorwahl', 'HausNrBis', 'HausNrVon', 'PLZ', 'TelefonVorwahl')]/d:wert"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 10"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 10">
               <xsl:attribute name="id">XGWA_MMTYPE_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 10.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'NeuAusgeuebt')]/d:wert"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1')">
               <xsl:attribute name="id">XGWA_MMTYPE_003_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonOrt', 'Doktorgrad', 'Familienname', 'Geburtsland', 'Geburtsname', 'Staatsangehoerigkeit', 'Vorname')]/d:wert"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 50">
               <xsl:attribute name="id">XGWA_MMTYPE_004_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BetriebsstaettenBezeichnung', 'EingetragenerName', 'IstBeteiligtAn', 'NameFirmaGewerbetreibender', 'Stichwort')]/d:wert"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 250"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 250">
               <xsl:attribute name="id">XGWA_MMTYPE_005_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 250.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnschriftZusatz', 'GemeindeMeldungNr', 'NamenZusatz', 'Strassenschluessel')]/d:wert"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 30"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 30">
               <xsl:attribute name="id">XGWA_MMTYPE_006_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 30.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungOrt', 'Geburtsort', 'Ort', 'Ortsteil')]/d:wert"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 60"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 60">
               <xsl:attribute name="id">XGWA_MMTYPE_007_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 60.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnlaesseUmmeldung', 'ArtHandwerkskarte', 'UrsacheAbmeldung')]/d:wert"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 150"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 150">
               <xsl:attribute name="id">XGWA_MMTYPE_008_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 150.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungNrSonstige', 'FaxNummer', 'TelefonNummer')]/d:wert"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 20"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 20">
               <xsl:attribute name="id">XGWA_MMTYPE_009_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 20.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte')]/d:wert"
                 priority="1045">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">XGWA_MMTYPE_010_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 5">
               <xsl:attribute name="id">XGWA_MMTYPE_010_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 5 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonName', 'Strasse')]/d:wert"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 100"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 100">
               <xsl:attribute name="id">XGWA_MMTYPE_011_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 100.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EMailAdresse', 'WebAdresse')]/d:wert"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 80"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 80">
               <xsl:attribute name="id">XGWA_MMTYPE_012_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 80.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GewerbebetriebID', 'UUID')]/d:wert"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 36"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 36">
               <xsl:attribute name="id">XGWA_MMTYPE_013_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 36.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_013_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AGSSchluesselVerzeichnis')]/d:wert"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 60 and string-length(.) le 79"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 60 and string-length(.) le 79">
               <xsl:attribute name="id">XGWA_MMTYPE_014_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 60 … 79.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*$')">
               <xsl:attribute name="id">XGWA_MMTYPE_014_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnzahlBeteiligte')]/d:wert"
                 priority="1040">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">XGWA_MMTYPE_015_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 3">
               <xsl:attribute name="id">XGWA_MMTYPE_015_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 3 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Auflagen')]/d:wert"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 300"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 300">
               <xsl:attribute name="id">XGWA_MMTYPE_016_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 300.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonSchluessel')]/d:wert"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('00001', '00002', '00003', '00004', '00005', '00006', '00007', '00008', '00009', '000011', '000012', '000015', '000016', '000018', '000019', '000021', '000023', '000024', '000025', '000026', '000027', '000031', '000032', '000033', '000034', '000035', '000037', '000038', '000043', '000044', '000045', '000051', '000052', '000053', '000054', '000061', '000062', '000063', '000064', '000065', '000066', '000067', '000068', '000071', '000072', '000074', '000075', '000076', '000078', '000081', '000091', '000092', '000093')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('00001', '00002', '00003', '00004', '00005', '00006', '00007', '00008', '00009', '000011', '000012', '000015', '000016', '000018', '000019', '000021', '000023', '000024', '000025', '000026', '000027', '000031', '000032', '000033', '000034', '000035', '000037', '000038', '000043', '000044', '000045', '000051', '000052', '000053', '000054', '000061', '000062', '000063', '000064', '000065', '000066', '000067', '000068', '000071', '000072', '000074', '000075', '000076', '000078', '000081', '000091', '000092', '000093')">
               <xsl:attribute name="id">XGWA_MMTYPE_017_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">XGWA_MMTYPE_018_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungArt')]/d:wert"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('A', 'B', 'G', 'V', 'X', 'S')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('A', 'B', 'G', 'V', 'X', 'S')">
               <xsl:attribute name="id">XGWA_MMTYPE_019_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungNr')]/d:wert"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 14"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 14">
               <xsl:attribute name="id">XGWA_MMTYPE_020_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 14.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9A-ZÄÖÜ]*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9A-ZÄÖÜ]*$')">
               <xsl:attribute name="id">XGWA_MMTYPE_020_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9A-ZÄÖÜ]*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GbRGesellschafter')]/d:wert"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 5000">
               <xsl:attribute name="id">XGWA_MMTYPE_021_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Geburtsdatum')]/d:wert"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">XGWA_MMTYPE_022_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')">
               <xsl:attribute name="id">XGWA_MMTYPE_022_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GemeindeSchluessel')]/d:wert"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">XGWA_MMTYPE_023_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GemeindeZusatz')]/d:wert"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 4">
               <xsl:attribute name="id">XGWA_MMTYPE_024_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GerichtSchluessel')]/d:wert"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('R3101', 'D3101', 'D3201', 'R1901', 'D4102', 'D2102', 'P3101', 'M1305', 'M1202', 'T2101V', 'R2108', 'D4201', 'D4301', 'F1103R', 'R2101', 'R2201', 'R3201', 'P1103', 'H1101', 'U1206', 'D4401', 'R2707', 'G1103', 'M1103', 'D2201', 'R2402', 'U1104', 'R1202', 'R3103', 'R1101', 'M1602', 'R2503', 'X1112R', 'G1207', 'M1201', 'B8536', 'M1405', 'M1603', 'M1301', 'D3304', 'R2507', 'M1406', 'P2204', 'R2103', 'R2602', 'K1101R', 'R2404', 'M1502', 'P2305', 'P2408', 'D4501', 'D5701', 'R2604', 'Y1206', 'T3201V', 'M1607', 'D2304', 'X1517R', 'R1304', 'T2210V', 'R3306', 'M1203', 'M1608', 'R1402', 'T3304V', 'D2404', 'U1308', 'R2307', 'M1706', 'X1721R', 'T3104V', 'P2507', 'T2304V', 'B8535', 'M1809', 'D2505', 'R1504', 'T2214V', 'D2601', 'R2713', 'N1105V', 'G1309', 'R1102', 'D3310', 'M1114', 'P3210', 'P3313', 'R2809', 'D2803', 'X1321R', 'G1312', 'R2204', 'D3410', 'N1206V', 'V1109', 'D4608', 'N1308V', 'R3208', 'R2909', 'P2106', 'R2706', 'W1215', 'N1209V', 'D3413', 'B8534', 'P2613', 'D2910', 'B8537', 'P2716', 'D3508', 'M1710', 'M1906', 'T2408V', 'R1608', 'D4708', 'T3403V')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('R3101', 'D3101', 'D3201', 'R1901', 'D4102', 'D2102', 'P3101', 'M1305', 'M1202', 'T2101V', 'R2108', 'D4201', 'D4301', 'F1103R', 'R2101', 'R2201', 'R3201', 'P1103', 'H1101', 'U1206', 'D4401', 'R2707', 'G1103', 'M1103', 'D2201', 'R2402', 'U1104', 'R1202', 'R3103', 'R1101', 'M1602', 'R2503', 'X1112R', 'G1207', 'M1201', 'B8536', 'M1405', 'M1603', 'M1301', 'D3304', 'R2507', 'M1406', 'P2204', 'R2103', 'R2602', 'K1101R', 'R2404', 'M1502', 'P2305', 'P2408', 'D4501', 'D5701', 'R2604', 'Y1206', 'T3201V', 'M1607', 'D2304', 'X1517R', 'R1304', 'T2210V', 'R3306', 'M1203', 'M1608', 'R1402', 'T3304V', 'D2404', 'U1308', 'R2307', 'M1706', 'X1721R', 'T3104V', 'P2507', 'T2304V', 'B8535', 'M1809', 'D2505', 'R1504', 'T2214V', 'D2601', 'R2713', 'N1105V', 'G1309', 'R1102', 'D3310', 'M1114', 'P3210', 'P3313', 'R2809', 'D2803', 'X1321R', 'G1312', 'R2204', 'D3410', 'N1206V', 'V1109', 'D4608', 'N1308V', 'R3208', 'R2909', 'P2106', 'R2706', 'W1215', 'N1209V', 'D3413', 'B8534', 'P2613', 'D2910', 'B8537', 'P2716', 'D3508', 'M1710', 'M1906', 'T2408V', 'R1608', 'D4708', 'T3403V')">
               <xsl:attribute name="id">XGWA_MMTYPE_025_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Geschlecht')]/d:wert"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">XGWA_MMTYPE_026_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundAbmeldungSchluessel')]/d:wert"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">XGWA_MMTYPE_027_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundAnmeldungSchluessel')]/d:wert"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">XGWA_MMTYPE_028_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundUmmeldungSchluessel')]/d:wert"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '99')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '99')">
               <xsl:attribute name="id">XGWA_MMTYPE_029_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Inhalt')]/d:wert"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 200"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 200">
               <xsl:attribute name="id">XGWA_MMTYPE_030_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 200.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('KorrekturGrundSchluessel')]/d:wert"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">XGWA_MMTYPE_031_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('MeldungArt')]/d:wert"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_032_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NATSchluesselVerzeichnis')]/d:wert"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_033_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_033_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NAT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NameOrganisation')]/d:wert"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 256">
               <xsl:attribute name="id">XGWA_MMTYPE_034_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NationSchluessel')]/d:wert"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 3">
               <xsl:attribute name="id">XGWA_MMTYPE_035_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NiederlassungArt')]/d:wert"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_036_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('PersonFunktion')]/d:wert"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_037_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('RechtsformSchluessel')]/d:wert"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('170', '180', '210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '310', '320', '321', '322', '323', '350', '351', '355', '356', '360', '400', '450', '510', '590', '610', '611', '700', '790', '911', '912', '921', '991', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('170', '180', '210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '310', '320', '321', '322', '323', '350', '351', '355', '356', '360', '400', '450', '510', '590', '610', '611', '700', '790', '911', '912', '921', '991', '992')">
               <xsl:attribute name="id">XGWA_MMTYPE_038_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('SGSSchluesselVerzeichnis')]/d:wert"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 77 and string-length(.) le 96"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 77 and string-length(.) le 96">
               <xsl:attribute name="id">XGWA_MMTYPE_039_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 77 … 96.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*$')">
               <xsl:attribute name="id">XGWA_MMTYPE_039_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('SatzErstellung')]/d:wert"
                 priority="1015">
      <xsl:variable name="year" select="substring(., 1, 4)"/>
      <xsl:variable name="month" select="substring(., 5, 2)"/>
      <xsl:variable name="day" select="substring(., 7, 2)"/>
      <xsl:variable name="hour" select="substring(., 9, 2)"/>
      <xsl:variable name="minute" select="substring(., 11, 2)"/>
      <xsl:variable name="second" select="substring(., 13, 2)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>
      <xsl:variable name="time" select="string-join(($hour, $minute, $second), ':')"/>
      <xsl:variable name="dateTime" select="concat($date, 'T', $time)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$dateTime castable as xs:dateTime"/>
         <xsl:otherwise>
            <svrl:failed-assert test="$dateTime castable as xs:dateTime">
               <xsl:attribute name="id">XGWA_MMTYPE_040_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="$dateTime"/>
                  <xsl:text/> ist kein gültiger Zeitpunkt.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Satzart')]/d:wert"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">XGWA_MMTYPE_041_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('StaatsangehoerigkeitSchluessel')]/d:wert"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 3">
               <xsl:attribute name="id">XGWA_MMTYPE_042_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9]{3}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9]{3}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_042_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9]{3}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Status')]/d:wert"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_043_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitEinzeln')]/d:wert"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 1000">
               <xsl:attribute name="id">XGWA_MMTYPE_044_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchluessel')]/d:wert"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5">
               <xsl:attribute name="id">XGWA_MMTYPE_045_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchwerpunkt')]/d:wert"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 1000">
               <xsl:attribute name="id">XGWA_MMTYPE_046_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitenZusammengefasst')]/d:wert"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5000">
               <xsl:attribute name="id">XGWA_MMTYPE_047_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('UrsacheAbmeldungSchluessel')]/d:wert"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')">
               <xsl:attribute name="id">XGWA_MMTYPE_048_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomentSchluessel')]/d:wert"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". castable as xs:integer and  xs:integer(.) = (01,02,03,04,05,06,07)"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". castable as xs:integer and xs:integer(.) = (01,02,03,04,05,06,07)">
               <xsl:attribute name="id">XGWA_MMTYPE_049_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomenteText')]/d:wert"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 900"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 900">
               <xsl:attribute name="id">XGWA_MMTYPE_050_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 900.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('Bemerkungen')]/d:wert"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 256">
               <xsl:attribute name="id">XGWA_MMTYPE_051_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerEmpfaenger')]/d:wert"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">XGWA_MMTYPE_052_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">XGWA_MMTYPE_053_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitIDZusatz')]/d:wert"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 4">
               <xsl:attribute name="id">XGWA_MMTYPE_054_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('GemeindeName')]/d:wert"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 50">
               <xsl:attribute name="id">XGWA_MMTYPE_055_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M6" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]"
                 priority="2118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ALGID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ALGID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ALGID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für ALGID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für ALGID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ALGID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_001_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ALGID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7">
               <xsl:attribute name="id">XGWA_OCCURS_001_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird höchstens 7 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']"
                 priority="2117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="2116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="2114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ALGID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ALGID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ALGID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ALGID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ALGID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_005_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ALGID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ALGID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_005_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ALGID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ALGID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="2113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_007_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_007_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_007_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="2110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_010_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="2108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="2107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_012_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="2106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_013_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_013_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="2105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_014_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_014_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="2104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_015_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_016_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_016_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_016_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="2101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="2100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="2099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="2098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_021_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_021_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="2097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_022_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_022_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="2096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_023_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_024_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_024_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_024_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="2093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="2092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_027_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_028_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_028_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_028_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="2089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_031_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="2087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_032_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="2086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="2085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_034_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ALGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_034_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ALGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="2084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="2083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="2082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_037_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="2081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_038_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_038_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_038_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_038_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_038_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="2080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_039_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="2079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_040_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_040_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mm"
                 priority="2078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')">
               <xsl:attribute name="id">XGWA_OCCURS_041_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr"
                 priority="2077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_042_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="2076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_043_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="2075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_044_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="2074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_045_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="2073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_046_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_047_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_048_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="2070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_049_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="2069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_050_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="2068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_051_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="2067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_052_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_053_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_054_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_055_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_056_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="2062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_057_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="2061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_058_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_059_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_060_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="2058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_061_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="2057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_062_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_063_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_064_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="2054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_065_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="2053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_066_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="2052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_067_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="2051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_068_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_069_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_070_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_071_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_072_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_073_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_074_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="2044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_075_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="2043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_076_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="2042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_077_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="2041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_078_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="2040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_079_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="2039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_080_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="2038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_081_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="2037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_082_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="2036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_083_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="2035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_084_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_085_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_086_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_087_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_088_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_089_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_090_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="2028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_091_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="2027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_092_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_093_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_094_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_095_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_096_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_097_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_098_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="2020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_099_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="2019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_100_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_101_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_102_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="2016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_103_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="2015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_104_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="2014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_105_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="2013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_106_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="2012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_107_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="2011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_108_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="2010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_109_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="2009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_110_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="2008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_111_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="2007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_112_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="2006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_113_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="2005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_114_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="2004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_115_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="2003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_116_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="2002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_117_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="2001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_118_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="2000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_119_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1999">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_120_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]"
                 priority="1998">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_121_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ASID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_121_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ASID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_121_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ASID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_121_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ASID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_121_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ASID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']"
                 priority="1997">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1996">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ASID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ASID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ASID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ASID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ASID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ASID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ASID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ASID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ASID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1995">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1994">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1993">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_126_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1992">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1991">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_128_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1990">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_129_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ASID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1989">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_130_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1988">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_131_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_131_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_131_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_131_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1987">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1986">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_133_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_133_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1985">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_134_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1984">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_135_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1983">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_136_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_136_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_136_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1982">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_137_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_137_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_137_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_137_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_137_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_137_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ASID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_137_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ASID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1981">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_138_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1980">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_139_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_139_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_139_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_139_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_139_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1979">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_140_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1978">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_141_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_141_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_141_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_141_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_141_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1977">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_142_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_142_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1976">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_143_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_143_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1975">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_144_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1974">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_145_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_145_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1973">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_146_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_146_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1972">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_147_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_147_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mm"
                 priority="1971">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_148_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr"
                 priority="1970">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_149_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1969">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_150_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1968">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_151_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1967">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_152_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1966">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_153_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1965">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_154_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1964">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_155_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1963">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_156_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1962">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_157_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1961">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_158_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1960">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_159_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1959">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_160_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1958">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_161_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1957">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_162_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1956">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_163_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1955">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_164_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1954">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_165_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1953">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_166_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1952">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_167_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1951">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_168_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1950">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_169_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1949">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_170_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1948">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_171_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1947">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_172_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1946">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_173_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1945">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_174_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1944">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_175_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1943">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_176_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1942">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_177_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1941">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_178_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1940">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_179_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1939">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_180_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1938">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_181_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1937">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_182_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1936">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_183_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1935">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_184_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1934">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_185_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1933">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_186_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1932">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_187_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1931">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_188_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1930">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_189_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1929">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_190_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1928">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_191_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1927">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_192_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1926">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_193_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1925">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_194_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1924">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_195_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1923">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_196_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1922">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_197_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1921">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_198_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1920">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_199_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1919">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_200_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1918">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_201_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]"
                 priority="1917">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für DGUID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für DGUID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_202_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für DGUID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für DGUID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für DGUID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für DGUID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_202_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für DGUID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']"
                 priority="1916">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1915">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_204_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für DGUID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für DGUID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für DGUID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für DGUID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für DGUID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_204_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für DGUID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_204_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für DGUID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_204_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für DGUID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_204_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für DGUID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1914">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1913">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_206_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_206_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_206_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_206_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_206_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_206_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_206_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1912">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1911">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_208_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1910">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1909">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_210_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1908">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_211_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_211_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_211_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_211_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_211_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1907">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_212_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_212_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1906">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_213_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1905">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_214_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_214_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_214_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_214_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_214_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_214_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_214_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1904">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_215_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_215_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_215_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_215_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_215_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_215_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_215_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1903">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_216_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1902">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_217_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_217_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_217_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_217_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_217_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_217_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1901">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_218_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_218_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1900">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_219_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_219_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1899">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_220_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_220_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_220_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_220_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_220_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_220_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_220_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1898">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_221_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_221_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1897">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_222_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_222_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_222_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_222_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_222_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_222_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_222_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1896">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_223_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_223_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_223_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1895">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_224_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_224_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_224_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_224_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_224_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_224_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für DGUID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_224_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für DGUID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1894">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_225_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1893">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_226_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_226_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_226_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_226_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_226_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1892">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_227_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1891">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_228_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_228_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_228_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_228_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_228_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1890">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_229_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_229_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1889">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_230_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_230_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1888">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_231_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1887">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_232_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_232_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1886">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_233_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_233_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1885">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_234_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_234_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mm"
                 priority="1884">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_235_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr"
                 priority="1883">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_236_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1882">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_237_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1881">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_238_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1880">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_239_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1879">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_240_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1878">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_241_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1877">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_242_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1876">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_243_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1875">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_244_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1874">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_245_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1873">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_246_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1872">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_247_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1871">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_248_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1870">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_249_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1869">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_250_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1868">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_251_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1867">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_252_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1866">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_253_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1865">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_254_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1864">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_255_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1863">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_256_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1862">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_257_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1861">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_258_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1860">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_259_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1859">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_260_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1858">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_261_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1857">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_262_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1856">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_263_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1855">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_264_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1854">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_265_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1853">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_266_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1852">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_267_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1851">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_268_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1850">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_269_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1849">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_270_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1848">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_271_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1847">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_272_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1846">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_273_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1845">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_274_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1844">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_275_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1843">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_276_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1842">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_277_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1841">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_278_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1840">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_279_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1839">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_280_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1838">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_281_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1837">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_282_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1836">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_283_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1835">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_284_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1834">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_285_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1833">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_286_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1832">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_287_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1831">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_288_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1830">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_289_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1829">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_290_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1828">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_291_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1827">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_292_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1826">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_293_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1825">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_294_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1824">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_295_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1823">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_296_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1822">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_297_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1821">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_298_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1820">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_299_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1819">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_300_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]"
                 priority="1818">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_301_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für EAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_301_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])">
               <xsl:attribute name="id">XGWA_OCCURS_301_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Die Bedingung für EAID.TaetigkeitenGesamt (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1817">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_302_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1816">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_303_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstNebenerwerb']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstNebenerwerb']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_303_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_303_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">XGWA_OCCURS_303_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1815">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_304_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_304_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">XGWA_OCCURS_304_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_304_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">XGWA_OCCURS_304_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">XGWA_OCCURS_304_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_304_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">XGWA_OCCURS_304_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_304_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_304_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1814">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_305_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_305_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1813">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_306_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für EAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_306_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1812">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_307_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_307_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für EAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_307_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1811">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_308_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_308_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_308_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_308_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_308_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_308_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_308_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_308_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1810">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_309_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_309_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">XGWA_OCCURS_309_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_309_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">XGWA_OCCURS_309_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">XGWA_OCCURS_309_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_309_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">XGWA_OCCURS_309_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_309_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_309_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1809">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_310_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_310_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für EAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_310_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1808">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_311_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für EAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_311_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1807">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_312_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_312_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_312_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1806">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_313_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_313_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_313_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_313_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_313_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_313_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für EAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_313_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für EAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1805">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_314_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1804">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_315_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_315_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_315_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_315_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_315_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1803">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_316_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1802">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_317_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_317_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_317_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_317_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_317_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1801">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_318_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_318_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mm"
                 priority="1800">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')">
               <xsl:attribute name="id">XGWA_OCCURS_319_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr"
                 priority="1799">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_320_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1798">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_321_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1797">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_322_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1796">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_323_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1795">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_324_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1794">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_325_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1793">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_326_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1792">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_327_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1791">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_328_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1790">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_329_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1789">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_330_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1788">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_331_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1787">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_332_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1786">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_333_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1785">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_334_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1784">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_335_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1783">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_336_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1782">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_337_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1781">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_338_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1780">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_339_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1779">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_340_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1778">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_341_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1777">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_342_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1776">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_343_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1775">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_344_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1774">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_345_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1773">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_346_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1772">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_347_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1771">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_348_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1770">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_349_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1769">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_350_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1768">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_351_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1767">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_352_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1766">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_353_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1765">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_354_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]"
                 priority="1764">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für FAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für FAID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_355_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für FAID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für FAID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_355_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für FAID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für FAID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_355_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für FAID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1763">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_356_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1762">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für FAID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für FAID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für FAID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für FAID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für FAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_357_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für FAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_357_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_357_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_357_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für FAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_357_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für FAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_357_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für FAID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1761">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_358_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1760">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_359_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_359_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1759">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_360_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_360_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1758">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_361_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1757">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_362_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_362_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1756">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_363_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_363_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_363_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_363_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1755">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_364_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_364_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1754">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_365_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_365_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1753">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_366_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_366_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_366_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_366_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_366_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_366_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_366_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1752">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_367_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_367_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_367_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_367_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_367_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1751">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_368_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1750">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_369_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_369_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_369_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_369_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_369_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_369_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1749">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_370_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1748">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_371_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_371_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_371_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_371_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1747">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_372_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_372_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1746">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_373_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_373_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1745">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_374_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_374_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_374_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_374_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_374_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_374_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_374_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1744">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_375_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_375_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_375_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_375_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_375_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1743">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_376_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1742">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_377_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_377_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1741">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_378_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_378_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_378_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_378_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_378_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_378_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_378_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1740">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_379_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_379_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_379_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_379_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_379_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1739">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_380_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_380_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_380_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1738">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_381_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_381_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_381_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_381_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_381_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_381_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für FAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_381_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für FAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1737">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_382_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1736">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_383_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_383_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_383_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_383_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_383_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1735">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_384_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1734">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_385_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_385_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_385_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_385_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_385_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1733">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_386_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_386_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1732">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_387_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_387_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1731">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_388_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1730">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_389_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_389_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1729">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_390_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_390_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1728">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_391_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_391_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mm"
                 priority="1727">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_392_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr"
                 priority="1726">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_393_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1725">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_394_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1724">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_395_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1723">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_396_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1722">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_397_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1721">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_398_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1720">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_399_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1719">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_400_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1718">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_401_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1717">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_402_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1716">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_403_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1715">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_404_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1714">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_405_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1713">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_406_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1712">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_407_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1711">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_408_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1710">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_409_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1709">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_410_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1708">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_411_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1707">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_412_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1706">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_413_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1705">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_414_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1704">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_415_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1703">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_416_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1702">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_417_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1701">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_418_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1700">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_419_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1699">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_420_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1698">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_421_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1697">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_422_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1696">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_423_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1695">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_424_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1694">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_425_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1693">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_426_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1692">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_427_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1691">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_428_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1690">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_429_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1689">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_430_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1688">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_431_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1687">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_432_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1686">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_433_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1685">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_434_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1684">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_435_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1683">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_436_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1682">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_437_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1681">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_438_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1680">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_439_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1679">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_440_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1678">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_441_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1677">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_442_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1676">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_443_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1675">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_444_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1674">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_445_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1673">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_446_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1672">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_447_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1671">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_448_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1670">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_449_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1669">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_450_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1668">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_451_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1667">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_452_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1666">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_453_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1665">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_454_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1664">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_455_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1663">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_456_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1662">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_457_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1661">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_458_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1660">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_459_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1659">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_460_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1658">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_461_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1657">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_462_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1656">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_463_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1655">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_464_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1654">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_465_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]"
                 priority="1653">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für HWKID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für HWKID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_466_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für HWKID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für HWKID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_466_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für HWKID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für HWKID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_466_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für HWKID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']"
                 priority="1652">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_467_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1651">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für HWKID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für HWKID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für HWKID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für HWKID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für HWKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_468_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für HWKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_468_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für HWKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_468_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für HWKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_468_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für HWKID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1650">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_469_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1649">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_470_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_470_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_470_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_470_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_470_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_470_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_470_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1648">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_471_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_471_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_471_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_471_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_471_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1647">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_472_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_472_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1646">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_473_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_473_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1645">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_474_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1644">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_475_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_475_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1643">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_476_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_476_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_476_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_476_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1642">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_477_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_477_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1641">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_478_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_478_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1640">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_479_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_479_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_479_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_479_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_479_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_479_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_479_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1639">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_480_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_480_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_480_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_480_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_480_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1638">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_481_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1637">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_482_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_482_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_482_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_482_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_482_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_482_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1636">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_483_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1635">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_484_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_484_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_484_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_484_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1634">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_485_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_485_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1633">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_486_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_486_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1632">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_487_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_487_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_487_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_487_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_487_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_487_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_487_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1631">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_488_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_488_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_488_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_488_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_488_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1630">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_489_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1629">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_490_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_490_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1628">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_491_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_491_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_491_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_491_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_491_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_491_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_491_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1627">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_492_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_492_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_492_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_492_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_492_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1626">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_493_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_493_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_493_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1625">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_494_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_494_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_494_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_494_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_494_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_494_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für HWKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_494_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für HWKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1624">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_495_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1623">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_496_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_496_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_496_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_496_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_496_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1622">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_497_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1621">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_498_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_498_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_498_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_498_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_498_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1620">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_499_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_499_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1619">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_500_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_500_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1618">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_501_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1617">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_502_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_502_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1616">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_503_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_503_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1615">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_504_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_504_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mm"
                 priority="1614">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_505_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr"
                 priority="1613">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_506_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1612">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_507_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1611">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_508_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1610">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_509_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1609">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_510_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1608">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_511_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1607">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_512_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1606">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_513_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1605">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_514_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1604">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_515_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1603">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_516_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1602">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_517_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1601">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_518_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1600">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_519_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1599">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_520_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1598">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_521_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1597">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_522_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1596">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_523_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1595">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_524_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1594">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_525_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1593">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_526_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1592">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_527_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1591">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_528_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1590">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_529_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1589">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_530_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1588">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_531_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1587">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_532_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1586">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_533_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1585">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_534_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1584">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_535_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1583">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_536_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1582">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_537_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1581">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_538_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1580">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_539_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1579">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_540_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1578">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_541_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1577">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_542_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1576">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_543_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1575">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_544_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1574">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_545_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1573">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_546_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1572">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_547_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1571">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_548_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1570">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_549_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1569">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_550_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1568">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_551_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1567">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_552_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1566">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_553_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1565">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_554_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1564">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_555_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1563">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_556_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1562">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_557_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1561">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_558_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1560">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_559_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1559">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_560_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1558">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_561_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1557">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_562_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1556">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_563_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1555">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_564_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1554">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_565_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1553">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_566_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1552">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_567_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1551">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_568_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1550">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_569_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1549">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_570_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1548">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_571_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1547">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_572_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1546">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_573_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1545">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_574_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1544">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_575_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1543">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_576_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1542">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_577_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1541">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_578_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1540">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_579_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1539">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_580_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1538">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_581_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1537">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_582_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]"
                 priority="1536">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für IHKID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für IHKID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_583_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für IHKID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für IHKID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_583_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für IHKID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für IHKID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_583_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für IHKID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']"
                 priority="1535">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_584_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1534">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für IHKID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für IHKID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für IHKID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für IHKID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für IHKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_585_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für IHKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_585_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_585_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für IHKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_585_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für IHKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_585_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für IHKID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1533">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_586_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1532">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_587_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_587_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_587_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_587_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_587_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1531">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_588_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_588_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1530">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_589_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_589_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1529">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_590_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1528">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_591_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_591_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1527">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_592_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_592_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_592_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_592_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_592_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1526">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_593_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_593_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1525">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_594_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_594_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1524">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_595_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_595_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_595_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_595_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_595_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1523">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_596_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1522">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_597_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_597_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_597_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_597_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_597_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_597_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_597_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1521">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_598_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1520">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_599_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_599_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_599_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_599_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_599_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1519">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_600_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_600_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1518">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_601_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_601_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1517">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_602_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_602_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_602_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_602_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_602_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1516">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_603_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1515">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_604_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_604_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1514">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_605_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_605_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_605_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_605_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_605_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1513">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_606_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_606_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_606_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1512">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_607_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_607_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_607_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_607_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_607_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_607_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für IHKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_607_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für IHKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1511">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_608_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1510">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_609_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_609_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_609_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_609_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_609_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1509">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_610_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1508">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_611_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_611_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_611_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_611_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_611_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1507">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_612_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_612_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1506">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_613_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_613_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1505">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_614_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1504">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_615_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_615_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1503">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_616_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_616_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1502">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_617_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_617_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mm"
                 priority="1501">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_618_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr"
                 priority="1500">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_619_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1499">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_620_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1498">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_621_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1497">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_622_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1496">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_623_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1495">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_624_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1494">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_625_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1493">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_626_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1492">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_627_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1491">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_628_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1490">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_629_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1489">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_630_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1488">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_631_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1487">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_632_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1486">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_633_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1485">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_634_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1484">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_635_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1483">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_636_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1482">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_637_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1481">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_638_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1480">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_639_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1479">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_640_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1478">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_641_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1477">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_642_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1476">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_643_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1475">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_644_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1474">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_645_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1473">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_646_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1472">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_647_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1471">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_648_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1470">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_649_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1469">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_650_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1468">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_651_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1467">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_652_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1466">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_653_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1465">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_654_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1464">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_655_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1463">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_656_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1462">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_657_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1461">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_658_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1460">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_659_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1459">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_660_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1458">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_661_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1457">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_662_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1456">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_663_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1455">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_664_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1454">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_665_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1453">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_666_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1452">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_667_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1451">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_668_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1450">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_669_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1449">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_670_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1448">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_671_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1447">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_672_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1446">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_673_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1445">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_674_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1444">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_675_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1443">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_676_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1442">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_677_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1441">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_678_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1440">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_679_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1439">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_680_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1438">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_681_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1437">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_682_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1436">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_683_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1435">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_684_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1434">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_685_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1433">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_686_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1432">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_687_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]"
                 priority="1431">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_688_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ISID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_688_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ISID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_688_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ISID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_688_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ISID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_688_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_688_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ISID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']"
                 priority="1430">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_689_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1429">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_690_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ISID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ISID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ISID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ISID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ISID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_690_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ISID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_690_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_690_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_690_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ISID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_690_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ISID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_690_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ISID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1428">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_691_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1427">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_692_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_692_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1426">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_693_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_693_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1425">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_694_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1424">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_695_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_695_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1423">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_696_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ISID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_696_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_696_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1422">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_697_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1421">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1420">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1419">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_700_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_700_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1418">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_701_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1417">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_702_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1416">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1415">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_704_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ISID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ISID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1414">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1413">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1412">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1411">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1410">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1409">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_710_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1408">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_711_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1407">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1406">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_713_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1405">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mm"
                 priority="1404">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_715_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr"
                 priority="1403">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_716_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1402">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_717_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1401">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_718_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1400">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_719_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1399">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_720_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1398">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_721_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1397">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_722_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1396">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_723_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1395">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_724_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1394">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_725_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1393">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_726_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1392">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_727_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1391">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_728_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1390">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_729_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1389">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_730_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1388">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_731_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1387">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_732_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1386">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_733_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1385">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_734_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1384">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_735_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1383">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_736_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1382">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_737_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1381">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_738_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1380">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_739_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1379">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_740_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1378">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_741_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1377">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_742_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1376">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_743_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1375">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_744_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1374">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_745_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1373">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_746_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1372">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_747_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1371">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_748_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1370">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_749_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1369">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_750_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1368">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_751_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1367">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_752_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1366">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_753_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1365">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_754_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1364">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_755_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1363">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_756_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1362">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_757_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1361">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_758_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1360">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_759_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1359">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_760_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1358">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_761_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1357">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_762_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1356">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_763_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1355">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_764_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1354">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_765_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1353">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_766_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1352">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_767_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1351">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_768_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]"
                 priority="1350">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für LUEID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für LUEID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_769_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für LUEID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für LUEID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für LUEID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']"
                 priority="1349">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1348">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_771_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für LUEID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für LUEID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für LUEID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für LUEID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für LUEID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_771_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für LUEID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_771_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_771_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für LUEID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_771_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für LUEID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für LUEID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1347">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1346">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1345">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_774_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1344">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1343">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_776_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1342">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_777_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für LUEID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_777_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1341">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_778_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1340">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_779_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_779_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_779_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_779_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_779_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_779_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_779_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_779_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1339">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1338">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_781_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_781_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1337">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_782_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1336">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_783_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1335">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1334">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_785_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_785_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_785_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_785_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_785_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_785_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für LUEID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_785_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für LUEID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1333">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_786_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1332">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_787_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_787_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_787_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_787_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_787_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1331">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_788_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1330">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_789_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_789_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_789_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_789_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_789_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1329">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_790_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_790_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1328">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_791_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_791_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1327">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_792_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1326">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_793_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_793_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1325">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_794_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_794_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1324">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_795_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_795_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mm"
                 priority="1323">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_796_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr"
                 priority="1322">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_797_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1321">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_798_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1320">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_799_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1319">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_800_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1318">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_801_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1317">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_802_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1316">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_803_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1315">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_804_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1314">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_805_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1313">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_806_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1312">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_807_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1311">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_808_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1310">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_809_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1309">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_810_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1308">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_811_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1307">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_812_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1306">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_813_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1305">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_814_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1304">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_815_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1303">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_816_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1302">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_817_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1301">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_818_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1300">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_819_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1299">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_820_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1298">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_821_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1297">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_822_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1296">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_823_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1295">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_824_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1294">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_825_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1293">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_826_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1292">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_827_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1291">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_828_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1290">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_829_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1289">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_830_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1288">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_831_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1287">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_832_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1286">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_833_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1285">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_834_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1284">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_835_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1283">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_836_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1282">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_837_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1281">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_838_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1280">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_839_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1279">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_840_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1278">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_841_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1277">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_842_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1276">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_843_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1275">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_844_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1274">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_845_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1273">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_846_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1272">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_847_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1271">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_848_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1270">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_849_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]"
                 priority="1269">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">XGWA_OCCURS_850_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für RGID.Satzart (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3' or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">XGWA_OCCURS_850_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für RGID.Satzart (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_850_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für RGID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_850_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_850_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für RGID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']"
                 priority="1268">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_851_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1267">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_852_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NiederlassungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NiederlassungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_852_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_852_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_852_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_852_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Hauptniederlassung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Hauptniederlassung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_852_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1266">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_853_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1265">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_854_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_854_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1264">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_855_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1263">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_856_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_856_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1262">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_857_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für RGID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_857_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_857_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1261">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_858_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_858_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1260">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_859_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_859_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_859_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_859_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_859_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_859_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_859_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_859_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1259">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_860_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1258">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_861_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_861_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_861_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1257">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_862_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_862_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1256">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_863_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_863_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1255">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_864_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_864_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_864_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1254">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_865_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_865_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_865_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_865_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_865_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_865_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für RGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_865_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für RGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1253">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_866_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1252">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_867_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_867_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_867_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_867_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_867_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1251">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_868_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1250">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_869_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_869_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_869_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_869_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_869_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1249">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_870_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_870_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1248">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_871_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_871_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1247">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_872_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_872_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mm"
                 priority="1246">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_873_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr"
                 priority="1245">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_874_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1244">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_875_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1243">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_876_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1242">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_877_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1241">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_878_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1240">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_879_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1239">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_880_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1238">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_881_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1237">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_882_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1236">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_883_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1235">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_884_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1234">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_885_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1233">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_886_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1232">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_887_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1231">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_888_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1230">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_889_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1229">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_890_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1228">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_891_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1227">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_892_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1226">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_893_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1225">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_894_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1224">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_895_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1223">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_896_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1222">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_897_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1221">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_898_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1220">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_899_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1219">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_900_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1218">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_901_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1217">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_902_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1216">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_903_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1215">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_904_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1214">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_905_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1213">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_906_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1212">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_907_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1211">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_908_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1210">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_909_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1209">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_910_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1208">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_911_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1207">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_912_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1206">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_913_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1205">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_914_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1204">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_915_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1203">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_916_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1202">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_917_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1201">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_918_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]"
                 priority="1200">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für STAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für STAID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">XGWA_OCCURS_919_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für STAID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_919_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für STAID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für STAID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für STAID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für STAID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1199">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1198">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für STAID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für STAID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für STAID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für STAID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für STAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_921_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für STAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_921_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_921_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für STAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_921_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für STAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für STAID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1197">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1196">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_923_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_923_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_923_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1195">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_924_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1194">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_925_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1193">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_926_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1192">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_927_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_927_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1191">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_928_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_928_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1190">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_929_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_929_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_929_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_929_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_929_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_929_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_929_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1189">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_930_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_930_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_930_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1188">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1187">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_932_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_932_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1186">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_933_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_933_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1185">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_934_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_934_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_934_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1184">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_935_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_935_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1183">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_936_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_936_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_936_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_936_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_936_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_936_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_936_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1182">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_937_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_937_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_937_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1181">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_938_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_938_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_938_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_938_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_938_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_938_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für STAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_938_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für STAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1180">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_939_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1179">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_940_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_940_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_940_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_940_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_940_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1178">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_941_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1177">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_942_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_942_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_942_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_942_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_942_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1176">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">XGWA_OCCURS_943_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_943_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1175">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_944_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_944_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1174">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_945_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1173">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">XGWA_OCCURS_946_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_946_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1172">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_947_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_947_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1171">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_948_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_948_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mm"
                 priority="1170">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_949_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr"
                 priority="1169">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_950_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1168">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_951_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1167">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_952_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1166">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_953_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1165">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_954_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1164">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_955_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1163">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_956_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1162">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_957_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1161">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_958_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1160">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_959_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1159">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_960_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1158">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_961_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1157">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_962_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1156">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_963_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1155">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_964_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1154">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_965_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1153">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_966_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1152">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_967_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1151">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_968_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1150">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_969_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1149">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_970_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1148">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_971_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1147">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_972_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1146">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_973_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1145">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_974_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1144">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_975_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1143">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_976_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1142">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_977_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1141">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_978_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1140">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_979_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1139">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_980_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1138">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_981_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1137">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_982_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1136">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_983_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1135">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_984_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1134">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_985_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1133">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_986_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1132">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_987_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1131">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_988_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_989_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_990_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_991_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_992_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_993_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_994_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_995_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_996_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_997_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_998_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_999_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1000_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_1001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_1003_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_1004_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1005_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1006_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_1007_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1008_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]"
                 priority="1110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">XGWA_OCCURS_1009_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für ZVID.Satzart (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">XGWA_OCCURS_1009_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für ZVID.Satzart (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1009_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ZVID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1009_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ZVID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1009_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']"
                 priority="1109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1010_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_1011_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ZVID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_1011_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ZVID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1011_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_1011_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ZVID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_1011_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ZVID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_1011_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">XGWA_OCCURS_1011_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1012_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1013_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_1013_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_1013_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1013_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1013_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1013_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1013_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1014_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1014_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1014_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1014_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1014_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1015_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1015_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1016_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1016_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1017_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1018_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1018_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_1019_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_1019_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_1019_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1019_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_1020_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1020_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1021_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1021_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1022_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_1022_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_1022_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1022_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1022_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1022_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1022_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1023_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1023_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1023_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1023_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1023_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1024_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1025_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1025_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1025_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_1025_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_1025_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1025_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1026_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_1027_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_1027_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_1027_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_1027_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_1028_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1028_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1029_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1029_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1030_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_1030_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_1030_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1030_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1030_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1030_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1030_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1031_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1031_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1031_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1031_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1031_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1032_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1033_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1033_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1034_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_1034_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_1034_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1034_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1034_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_1034_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1034_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1035_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1035_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1035_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1035_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1035_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1036_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1036_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1036_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1037_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1037_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1037_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1037_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1037_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">XGWA_OCCURS_1037_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ZVID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">XGWA_OCCURS_1037_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ZVID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1038_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_1039_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1039_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1039_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1039_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1039_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1040_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">XGWA_OCCURS_1041_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1041_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1041_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1041_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_1041_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1042_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1042_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">XGWA_OCCURS_1043_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1043_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_1044_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1045_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_1045_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mm"
                 priority="1073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText')">
               <xsl:attribute name="id">XGWA_OCCURS_1046_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr"
                 priority="1072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_1047_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1048_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1049_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_1050_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_1051_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_1052_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1053_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_1054_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1055_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_1056_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1057_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_1058_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1059_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1060_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1061_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1062_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_1063_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1064_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1065_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_1066_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_1067_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_1068_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1069_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1070_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1071_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_1072_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1073_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_1074_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1075_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_1076_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1077_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_1078_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_1079_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">XGWA_OCCURS_1080_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1081_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_1082_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_1083_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_1084_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1085_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1086_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1087_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_1088_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1089_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_1090_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1091_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_1092_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1093_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1094_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1095_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_1096_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1097_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_1098_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1099_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1100_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_1101_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_1102_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1103_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_1104_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_1105_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_1106_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1107_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">XGWA_OCCURS_1108_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_1109_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_1110_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1111_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_1112_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_1113_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_1114_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1115_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_1116_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1117_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_1118_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1119_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M7" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template xmlns:sdf="http://www.destatis.de/schema/datml-sdf/2.0"
                 xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001schematron-select-full-path"
                 match="*">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="local-name()"/>
         <xsl:choose>
            <xsl:when test="local-name()='satz' and d:mm[@name='UUID']/d:wert">
               <xsl:text>[mm[@name='UUID' and wert='</xsl:text>
               <xsl:value-of select="d:mm[@name='UUID']/d:wert"/>
               <xsl:text>']]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='satz'">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="position()"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='mmgr' or local-name()='mm'">
               <xsl:text>[@name='</xsl:text>
               <xsl:value-of select="@name"/>
               <xsl:text>']</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[name(.) = name(current())] or       following-sibling::*[name(.) = name(current())]">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="count(preceding-sibling::*[name(.) = name(current())]) + 1"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
         </xsl:choose>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="/"/>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="text()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.text-', 1 + count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="comment()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.comment-', 1 + count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="processing-instruction()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.processing-instruction-', 1 + count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="@*">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="*"
                 priority="-0.5">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.', name(), '-', 1 + count(preceding-sibling::*[name() = name(current())]), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="/">U</xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="*"
                 priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="node()">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="@*">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(), ':', '.')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001"
                 match="text()"
                 priority="-1"/>
   <xsl:template mode="M_00041740059999000001" match="/">
      <rep:pruefprotokoll xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll">
         <xsl:sequence select="/d:DatML-RAW-D/(d:optionen|d:protokoll|d:absender|d:empfaenger)"/>
         <svrl:schematron-output title="GWA-Schematron-Validierer für XGewerbeanzeige (Version 1.2)"
                                 schemaVersion="00041740059999000001">
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_APPL</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Anwendbarkeit der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M2" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_HMM</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Erforderliche und zulässige Hilfsmerkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M3" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMDEF</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmale der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M4" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMGRDEF</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmalsgruppen der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M5" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_MMTYPE</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Datentypen der Merkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M6" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">XGWA_OCCURS</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Häufigkeiten und Bedingungen</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M7" select="/"/>
         </svrl:schematron-output>
      </rep:pruefprotokoll>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2"
                 match="d:nachricht/d:erhebung"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:kennung[@klasse = 'ERHID'] = '0004'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:kennung[@klasse = 'ERHID'] = '0004'">
               <xsl:attribute name="id">XGWA_APPL_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Element d:kennung muss vorhanden sein und den Wert 0004 haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2"
                 match="d:nachricht/d:berichtszeitraum"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2017-05'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2017-05'">
               <xsl:attribute name="id">XGWA_APPL_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Der Berichtszeitraum der Nachricht (<xsl:text/>
                  <xsl:value-of select="concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
                  <xsl:text/>) darf nicht vor der Wirksamkeit dieser Lieferbeschreibung liegen (ausgenommen Testlieferungen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M2" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3" match="d:nachricht" priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1">
               <xsl:attribute name="id">XGWA_HMM_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitIDZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'GemeindeName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'GemeindeName']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'Bemerkungen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'Bemerkungen']) le 1">
               <xsl:attribute name="id">XGWA_HMM_001_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Bemerkungen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1">
               <xsl:attribute name="id">XGWA_HMM_001_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerEmpfaenger: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3"
                 match="d:nachricht/d:hmm"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')">
               <xsl:attribute name="id">XGWA_HMM_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Hilfsmerkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M3" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M4" match="d:mm" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AGSSchluesselVerzeichnis', 'ANRSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnredeSchluessel', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'FKSSchluesselVerzeichnis', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HWKSchluesselVerzeichnis', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NTTSchluesselVerzeichnis', 'NachtitelSchluessel', 'NameFirmaGewerbetreibender', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'PostfachNummer', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachPLZ', 'RFMSchluesselVerzeichnis', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'STWVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TITSchluesselVerzeichnis', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'Titel', 'TitelSchluessel', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WZGSchluesselVerzeichnis', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AGSSchluesselVerzeichnis', 'ANRSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnredeSchluessel', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'FKSSchluesselVerzeichnis', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HWKSchluesselVerzeichnis', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NTTSchluesselVerzeichnis', 'NachtitelSchluessel', 'NameFirmaGewerbetreibender', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'PostfachNummer', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachPLZ', 'RFMSchluesselVerzeichnis', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'STWVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TITSchluesselVerzeichnis', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'Titel', 'TitelSchluessel', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WZGSchluesselVerzeichnis', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_MMDEF_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmal definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M4" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M4" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M5" match="d:mmgr" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'Taetigkeiten', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'Taetigkeiten', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson')">
               <xsl:attribute name="id">XGWA_MMGRDEF_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmalsgruppe definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M5" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M5" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltAm', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'DatumMeldung', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'GueltigAb')]/d:wert"
                 priority="1061">
      <xsl:variable name="day" select="substring(., 1, 2)"/>
      <xsl:variable name="month" select="substring(., 3, 2)"/>
      <xsl:variable name="year" select="substring(., 5, 4)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^\d{8}$') and $date castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^\d{8}$') and $date castable as xs:date">
               <xsl:attribute name="id">XGWA_MMTYPE_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein gültiges Datum (<xsl:text/>
                  <xsl:value-of select="$date"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonPLZ', 'Begriff', 'EintragungPLZ', 'FaxVorwahl', 'HausNrBis', 'HausNrVon', 'PLZ', 'PostfachPLZ', 'TelefonVorwahl')]/d:wert"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 10"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 10">
               <xsl:attribute name="id">XGWA_MMTYPE_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 10.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'NeuAusgeuebt')]/d:wert"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1')">
               <xsl:attribute name="id">XGWA_MMTYPE_003_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonOrt', 'Familienname', 'Geburtsland', 'Geburtsname', 'Staatsangehoerigkeit', 'Titel', 'Vorname')]/d:wert"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 50">
               <xsl:attribute name="id">XGWA_MMTYPE_004_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('BetriebsstaettenBezeichnung', 'EingetragenerName', 'IstBeteiligtAn', 'NameFirmaGewerbetreibender', 'Stichwort')]/d:wert"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 250"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 250">
               <xsl:attribute name="id">XGWA_MMTYPE_005_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 250.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungOrt', 'Geburtsort', 'Ort', 'Ortsteil', 'PostfachOrt')]/d:wert"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 60"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 60">
               <xsl:attribute name="id">XGWA_MMTYPE_006_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 60.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnschriftZusatz', 'GemeindeMeldungNr', 'NamenZusatz', 'Strassenschluessel')]/d:wert"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 30"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 30">
               <xsl:attribute name="id">XGWA_MMTYPE_007_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 30.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnlaesseUmmeldung', 'ArtHandwerkskarte', 'UrsacheAbmeldung')]/d:wert"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 150"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 150">
               <xsl:attribute name="id">XGWA_MMTYPE_008_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 150.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnredeSchluessel', 'NachtitelSchluessel', 'TitelSchluessel')]/d:wert"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 2">
               <xsl:attribute name="id">XGWA_MMTYPE_009_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 2.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungNrAusland', 'FaxNummer', 'TelefonNummer')]/d:wert"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 20"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 20">
               <xsl:attribute name="id">XGWA_MMTYPE_010_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 20.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte')]/d:wert"
                 priority="1051">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">XGWA_MMTYPE_011_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 5">
               <xsl:attribute name="id">XGWA_MMTYPE_011_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 5 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonName', 'Strasse')]/d:wert"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 100"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 100">
               <xsl:attribute name="id">XGWA_MMTYPE_012_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 100.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EMailAdresse', 'WebAdresse')]/d:wert"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 80"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 80">
               <xsl:attribute name="id">XGWA_MMTYPE_013_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 80.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GewerbebetriebID', 'UUID')]/d:wert"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 36"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 36">
               <xsl:attribute name="id">XGWA_MMTYPE_014_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 36.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_014_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NationSchluessel', 'PostfachOrtNationSchluessel')]/d:wert"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 3">
               <xsl:attribute name="id">XGWA_MMTYPE_015_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RechtsformSchluessel', 'StaatsangehoerigkeitSchluessel')]/d:wert"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 3">
               <xsl:attribute name="id">XGWA_MMTYPE_016_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AGSSchluesselVerzeichnis')]/d:wert"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_017_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^AGS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^AGS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_017_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster AGS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('ANRSchluesselVerzeichnis')]/d:wert"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_018_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^ANR(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^ANR(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_018_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ANR(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnzahlBeteiligte')]/d:wert"
                 priority="1043">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">XGWA_MMTYPE_019_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) lt 3">
               <xsl:attribute name="id">XGWA_MMTYPE_019_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 3 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Auflagen')]/d:wert"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 300"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 300">
               <xsl:attribute name="id">XGWA_MMTYPE_020_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 300.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonSchluessel')]/d:wert"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 3 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 3 and string-length(.) le 5">
               <xsl:attribute name="id">XGWA_MMTYPE_021_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 3 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungArt')]/d:wert"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('A', 'B', 'G', 'V', 'X')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('A', 'B', 'G', 'V', 'X')">
               <xsl:attribute name="id">XGWA_MMTYPE_022_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungNr')]/d:wert"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 14"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 14">
               <xsl:attribute name="id">XGWA_MMTYPE_023_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 14.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9A-Z]*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9A-Z]*$')">
               <xsl:attribute name="id">XGWA_MMTYPE_023_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9A-Z]*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('FKSSchluesselVerzeichnis')]/d:wert"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_024_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^FKS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^FKS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_024_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster FKS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Geburtsdatum')]/d:wert"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">XGWA_MMTYPE_025_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')">
               <xsl:attribute name="id">XGWA_MMTYPE_025_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GemeindeSchluessel')]/d:wert"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">XGWA_MMTYPE_026_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GemeindeZusatz')]/d:wert"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 4">
               <xsl:attribute name="id">XGWA_MMTYPE_027_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GerichtSchluessel')]/d:wert"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 6 and string-length(.) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 6 and string-length(.) le 7">
               <xsl:attribute name="id">XGWA_MMTYPE_028_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 6 … 7.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Geschlecht')]/d:wert"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">XGWA_MMTYPE_029_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundAbmeldungSchluessel')]/d:wert"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">XGWA_MMTYPE_030_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundAnmeldungSchluessel')]/d:wert"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">XGWA_MMTYPE_031_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundUmmeldungSchluessel')]/d:wert"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15')">
               <xsl:attribute name="id">XGWA_MMTYPE_032_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('HWKSchluesselVerzeichnis')]/d:wert"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_033_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^HWK(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^HWK(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_033_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster HWK(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Inhalt')]/d:wert"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 200"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 200">
               <xsl:attribute name="id">XGWA_MMTYPE_034_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 200.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('KorrekturGrundSchluessel')]/d:wert"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">XGWA_MMTYPE_035_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('MeldungArt')]/d:wert"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_036_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NATSchluesselVerzeichnis')]/d:wert"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_037_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_037_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NAT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NTTSchluesselVerzeichnis')]/d:wert"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_038_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NTT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NTT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_038_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NTT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NiederlassungArt')]/d:wert"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_039_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('PersonFunktion')]/d:wert"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_040_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('PostfachNummer')]/d:wert"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 8">
               <xsl:attribute name="id">XGWA_MMTYPE_041_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RFMSchluesselVerzeichnis')]/d:wert"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_042_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^RFM(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^RFM(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_042_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster RFM(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RGGSchluesselVerzeichnis')]/d:wert"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_043_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^RGG(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^RGG(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_043_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster RGG(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('SGSSchluesselVerzeichnis')]/d:wert"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_044_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^SGS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^SGS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_044_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster SGS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('STWVerzeichnis')]/d:wert"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_045_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^STW(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^STW(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_045_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster STW(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('SatzErstellung')]/d:wert"
                 priority="1016">
      <xsl:variable name="year" select="substring(., 1, 4)"/>
      <xsl:variable name="month" select="substring(., 5, 2)"/>
      <xsl:variable name="day" select="substring(., 7, 2)"/>
      <xsl:variable name="hour" select="substring(., 9, 2)"/>
      <xsl:variable name="minute" select="substring(., 11, 2)"/>
      <xsl:variable name="second" select="substring(., 13, 2)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>
      <xsl:variable name="time" select="string-join(($hour, $minute, $second), ':')"/>
      <xsl:variable name="dateTime" select="concat($date, 'T', $time)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$dateTime castable as xs:dateTime"/>
         <xsl:otherwise>
            <svrl:failed-assert test="$dateTime castable as xs:dateTime">
               <xsl:attribute name="id">XGWA_MMTYPE_046_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="$dateTime"/>
                  <xsl:text/> ist kein gültiger Zeitpunkt.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Satzart')]/d:wert"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">XGWA_MMTYPE_047_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Status')]/d:wert"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1', '2', '3')">
               <xsl:attribute name="id">XGWA_MMTYPE_048_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TITSchluesselVerzeichnis')]/d:wert"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_049_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^TIT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^TIT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_049_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster TIT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitEinzeln')]/d:wert"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 1000">
               <xsl:attribute name="id">XGWA_MMTYPE_050_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchluessel')]/d:wert"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5">
               <xsl:attribute name="id">XGWA_MMTYPE_051_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchwerpunkt')]/d:wert"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 1000">
               <xsl:attribute name="id">XGWA_MMTYPE_052_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitenZusammengefasst')]/d:wert"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5000">
               <xsl:attribute name="id">XGWA_MMTYPE_053_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('UrsacheAbmeldungSchluessel')]/d:wert"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')">
               <xsl:attribute name="id">XGWA_MMTYPE_054_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomentSchluessel')]/d:wert"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". castable as xs:integer and  xs:integer(.) = (01,02,03,04,05,06,07)"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". castable as xs:integer and xs:integer(.) = (01,02,03,04,05,06,07)">
               <xsl:attribute name="id">XGWA_MMTYPE_055_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomenteText')]/d:wert"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 900"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 900">
               <xsl:attribute name="id">XGWA_MMTYPE_056_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 900.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('WZGSchluesselVerzeichnis')]/d:wert"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">XGWA_MMTYPE_057_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^WZG(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^WZG(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">XGWA_MMTYPE_057_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster WZG(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('Bemerkungen')]/d:wert"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 256">
               <xsl:attribute name="id">XGWA_MMTYPE_058_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerEmpfaenger')]/d:wert"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">XGWA_MMTYPE_059_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">XGWA_MMTYPE_060_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitIDZusatz')]/d:wert"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 4">
               <xsl:attribute name="id">XGWA_MMTYPE_061_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('GemeindeName')]/d:wert"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 50">
               <xsl:attribute name="id">XGWA_MMTYPE_062_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M6" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]"
                 priority="2001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel'][1]/d:wert/xs:integer(.) = (1, 2, 3, 4, 5, 6, 7)) or exists(d:mm[@name eq 'FKSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel'][1]/d:wert/xs:integer(.) = (1, 2, 3, 4, 5, 6, 7)) or exists(d:mm[@name eq 'FKSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FKSSchluesselVerzeichnis: Die Bedingung L12.15 (Verdachtsmomente[1].VerdachtsmomentSchluessel IN {01++07}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L12.08 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L12.07 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L12.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L12.09 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_001_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L12.10 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_001_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7">
               <xsl:attribute name="id">XGWA_OCCURS_001_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird höchstens 7 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="2000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_002_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1999">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_003_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1998">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L12.11 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L12.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L12.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L12.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_004_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_004_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_004_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_004_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1997">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_005_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_005_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1996">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_006_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_006_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_006_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_006_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_006_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1995">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_007_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1994">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_008_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1993">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_009_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1992">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_010_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1991">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_011_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1990">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_012_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_012_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_012_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_012_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_012_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1989">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_013_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_013_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1988">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_014_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1987">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_015_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_015_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_015_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_015_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_015_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1986">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_016_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1985">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_017_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1984">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_018_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1983">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_019_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_019_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1982">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_020_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_020_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_020_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_020_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_020_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1981">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_021_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_021_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1980">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_022_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1979">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_023_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_023_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_023_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_023_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_023_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1978">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_024_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1977">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_025_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1976">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_026_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1975">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_027_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_027_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_027_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_027_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_027_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1974">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_028_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1973">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_029_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1972">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_030_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1971">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_031_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1970">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_032_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_032_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1969">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_033_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_033_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1968">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_034_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_034_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_034_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1967">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_035_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_035_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1966">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_036_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1965">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_037_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_037_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mm"
                 priority="1964">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')">
               <xsl:attribute name="id">XGWA_OCCURS_038_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr"
                 priority="1963">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_039_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1962">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_040_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1961">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_041_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1960">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_042_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1959">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_043_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1958">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_044_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1957">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_045_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1956">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_046_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1955">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_047_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1954">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_048_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1953">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_049_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1952">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_050_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1951">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_051_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1950">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_052_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1949">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_053_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1948">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_054_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1947">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_055_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1946">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_056_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1945">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_057_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1944">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_058_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1943">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_059_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1942">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_060_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1941">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_061_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1940">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_062_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1939">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_063_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1938">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_064_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1937">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_065_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1936">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_066_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1935">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_067_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1934">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_068_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1933">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_069_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1932">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_070_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1931">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_071_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1930">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_072_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1929">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_073_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1928">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_074_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1927">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_075_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1926">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_076_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1925">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_077_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1924">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_078_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1923">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_079_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1922">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_080_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1921">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_081_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1920">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_082_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1919">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_083_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1918">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_084_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1917">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_085_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1916">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_086_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1915">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_087_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1914">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_088_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1913">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_089_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1912">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_090_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1911">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_091_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1910">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_092_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1909">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_093_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1908">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_094_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1907">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_095_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1906">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_096_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1905">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_097_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1904">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_098_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1903">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_099_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1902">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_100_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1901">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_101_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1900">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_102_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1899">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_103_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1898">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_104_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1897">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_105_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1896">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_106_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1895">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_107_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1894">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_108_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1893">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_109_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1892">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_110_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1891">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_111_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]"
                 priority="1890">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_112_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L11.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_112_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L11.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_112_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_112_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L11.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1889">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_113_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L11.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L11.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L11.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L11.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_113_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_113_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_113_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_113_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_113_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_113_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1888">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_114_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_114_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1887">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_115_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_115_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1886">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_116_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1885">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_117_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1884">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_118_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1883">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_119_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_119_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_119_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_119_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_119_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_119_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1882">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_120_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1881">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_121_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_121_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_121_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_121_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_121_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1880">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_122_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_122_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1879">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_123_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_123_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_123_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1878">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_124_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1877">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_125_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1876">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_126_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_126_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1875">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_127_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_127_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_127_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_127_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1874">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_128_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_128_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_128_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1873">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_129_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_129_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_129_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1872">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_130_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1871">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_131_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1870">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_132_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1869">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_133_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1868">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_134_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1867">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_135_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mm"
                 priority="1866">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_136_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr"
                 priority="1865">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_137_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1864">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_138_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1863">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_139_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1862">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_140_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1861">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_141_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1860">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_142_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1859">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_143_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1858">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_144_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1857">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_145_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1856">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_146_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1855">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_147_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1854">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_148_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1853">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_149_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1852">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_150_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1851">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_151_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1850">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_152_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1849">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_153_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1848">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_154_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1847">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_155_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1846">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_156_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1845">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_157_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1844">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_158_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1843">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_159_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1842">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_160_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1841">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_161_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1840">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_162_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1839">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_163_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1838">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_164_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1837">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_165_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1836">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_166_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1835">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_167_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1834">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_168_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1833">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_169_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1832">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_170_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1831">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_171_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1830">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_172_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1829">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_173_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1828">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_174_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1827">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_175_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1826">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_176_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1825">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_177_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1824">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_178_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1823">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_179_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1822">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_180_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1821">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_181_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1820">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_182_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1819">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_183_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]"
                 priority="1818">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_184_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L06.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_184_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L06.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_184_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_184_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L06.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_184_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L06.07 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_184_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L06.08 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1817">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_185_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L06.19 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L06.20 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L06.21 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L06.22 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_185_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_185_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_185_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_185_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_185_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1816">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_186_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_186_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1815">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_187_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_187_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_187_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_187_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_187_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_187_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_187_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_187_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1814">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_188_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_188_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1813">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_189_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1812">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_190_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1811">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_191_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1810">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_192_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_192_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_192_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_192_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_192_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_192_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_192_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_192_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_192_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1809">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_193_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_193_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1808">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_194_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1807">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_195_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_195_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_195_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_195_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_195_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_195_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_195_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_195_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1806">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_196_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_196_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_196_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_196_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_196_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_196_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_196_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1805">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_197_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_197_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1804">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_198_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_198_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_198_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_198_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_198_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_198_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_198_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_198_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_198_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1803">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_199_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_199_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1802">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_200_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1801">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_201_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_201_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_201_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_201_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_201_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_201_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_201_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_201_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1800">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_202_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1799">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_203_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_203_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_203_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_203_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_203_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1798">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_204_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_204_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1797">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_205_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_205_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_205_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_205_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1796">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_206_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_206_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_206_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1795">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_207_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_207_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_207_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_207_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1794">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_208_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1793">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_209_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1792">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_210_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1791">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_211_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1790">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_212_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1789">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_213_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mm"
                 priority="1788">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_214_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr"
                 priority="1787">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_215_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1786">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_216_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1785">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_217_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1784">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_218_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1783">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_219_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1782">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_220_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1781">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_221_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1780">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_222_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1779">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_223_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1778">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_224_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1777">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_225_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1776">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_226_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1775">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_227_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1774">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_228_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1773">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_229_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1772">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_230_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1771">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_231_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1770">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_232_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1769">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_233_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1768">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_234_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1767">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_235_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1766">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_236_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1765">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_237_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1764">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_238_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1763">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_239_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1762">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_240_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1761">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_241_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1760">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_242_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1759">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_243_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1758">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_244_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1757">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_245_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1756">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_246_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1755">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_247_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1754">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_248_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1753">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_249_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1752">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_250_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1751">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_251_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1750">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_252_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1749">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_253_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1748">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_254_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1747">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_255_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1746">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_256_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1745">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_257_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1744">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_258_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1743">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_259_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1742">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_260_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1741">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_261_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1740">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_262_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1739">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_263_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1738">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_264_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1737">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_265_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1736">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_266_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1735">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_267_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1734">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_268_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1733">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_269_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1732">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_270_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1731">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_271_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1730">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_272_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1729">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_273_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]"
                 priority="1728">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_274_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L07.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_274_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])">
               <xsl:attribute name="id">XGWA_OCCURS_274_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Die Bedingung L07.50 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1727">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_275_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstNebenerwerb']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstNebenerwerb']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_275_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_275_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">XGWA_OCCURS_275_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1726">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_276_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_276_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_276_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_276_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_276_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_276_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1725">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_277_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_277_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1724">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_278_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1723">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_279_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_279_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_279_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_279_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_279_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_279_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1722">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_280_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_280_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_280_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_280_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_280_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_280_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_280_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_280_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1721">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_281_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_281_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_281_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_281_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_281_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_281_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1720">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_282_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_282_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_282_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_282_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_282_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_282_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1719">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_283_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1718">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_284_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_284_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1717">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_285_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_285_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_285_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_285_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_285_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_285_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_285_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_285_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1716">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_286_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_286_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_286_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1715">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_287_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_287_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_287_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_287_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_287_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_287_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_287_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1714">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_288_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_288_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mm"
                 priority="1713">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')">
               <xsl:attribute name="id">XGWA_OCCURS_289_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr"
                 priority="1712">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_290_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1711">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_291_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1710">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_292_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1709">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_293_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1708">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_294_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1707">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_295_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1706">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_296_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1705">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_297_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1704">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_298_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1703">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_299_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1702">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_300_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1701">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_301_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1700">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_302_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1699">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_303_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1698">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_304_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1697">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_305_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1696">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_306_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1695">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_307_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1694">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_308_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1693">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_309_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1692">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_310_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1691">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_311_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1690">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_312_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1689">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_313_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1688">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_314_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1687">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_315_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1686">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_316_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1685">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_317_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1684">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_318_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]"
                 priority="1683">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_319_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L08.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_319_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L08.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_319_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_319_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L08.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_319_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L08.23 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_319_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L08.24 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1682">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L08.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L08.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L08.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L08.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_320_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_320_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_320_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_320_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_320_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_320_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1681">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_321_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_321_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1680">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_322_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_322_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1679">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_323_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1678">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_324_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1677">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_325_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1676">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_326_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_326_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_326_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_326_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_326_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_326_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_326_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1675">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_327_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_327_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1674">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_328_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1673">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_329_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_329_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_329_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_329_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_329_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_329_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_329_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_329_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1672">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_330_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_330_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_330_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_330_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_330_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1671">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_331_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1670">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_332_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_332_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_332_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_332_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_332_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_332_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1669">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_333_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_333_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1668">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_334_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_334_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_334_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_334_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_334_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_334_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_334_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1667">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_335_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_335_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1666">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_336_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1665">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_337_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_337_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_337_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_337_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_337_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_337_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_337_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_337_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1664">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_338_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_338_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_338_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_338_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_338_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1663">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_339_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1662">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_340_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1661">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_341_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_341_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_341_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_341_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_341_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_341_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_341_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_341_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1660">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_342_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_342_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_342_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_342_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_342_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1659">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_343_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_343_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1658">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_344_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_344_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_344_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_344_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_344_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_344_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_344_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_344_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1657">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_345_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_345_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_345_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1656">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_346_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_346_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_346_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_346_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_346_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_346_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_346_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1655">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_347_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_347_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1654">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_348_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1653">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_349_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1652">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_350_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_350_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1651">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_351_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1650">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_352_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_352_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mm"
                 priority="1649">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_353_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr"
                 priority="1648">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_354_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1647">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_355_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1646">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_356_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1645">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_357_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1644">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_358_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1643">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_359_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1642">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_360_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1641">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_361_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1640">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_362_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1639">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_363_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1638">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_364_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1637">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_365_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1636">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_366_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1635">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_367_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1634">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_368_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1633">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_369_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1632">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_370_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1631">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_371_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1630">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_372_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1629">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_373_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1628">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_374_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1627">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_375_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1626">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_376_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1625">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_377_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1624">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_378_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1623">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_379_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1622">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_380_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1621">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_381_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1620">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_382_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1619">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_383_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1618">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_384_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1617">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_385_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1616">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_386_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1615">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_387_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1614">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_388_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1613">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_389_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1612">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_390_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1611">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_391_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1610">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_392_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1609">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_393_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1608">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_394_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1607">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_395_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1606">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_396_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1605">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_397_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1604">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_398_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1603">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_399_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1602">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_400_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1601">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_401_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1600">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_402_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1599">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_403_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1598">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_404_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1597">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_405_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1596">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_406_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1595">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_407_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1594">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_408_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1593">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_409_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1592">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_410_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1591">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_411_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1590">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_412_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1589">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_413_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1588">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_414_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1587">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_415_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1586">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_416_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1585">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_417_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1584">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_418_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1583">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_419_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1582">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_420_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]"
                 priority="1581">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_421_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L03.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_421_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L03.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_421_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_421_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L03.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_421_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L03.07 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_421_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L03.08 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1580">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L03.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L03.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L03.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L03.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_422_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_422_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_422_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_422_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1579">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_423_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_423_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1578">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_424_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_424_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_424_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_424_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_424_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_424_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_424_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_424_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1577">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_425_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_425_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_425_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_425_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_425_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1576">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_426_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_426_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1575">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_427_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1574">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_428_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1573">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_429_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1572">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_430_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_430_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_430_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_430_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_430_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_430_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_430_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1571">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_431_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_431_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1570">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_432_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1569">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_433_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_433_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_433_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_433_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_433_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_433_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_433_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_433_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1568">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_434_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_434_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_434_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_434_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_434_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1567">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_435_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1566">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_436_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_436_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_436_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_436_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_436_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_436_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1565">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_437_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_437_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1564">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_438_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_438_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_438_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_438_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_438_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_438_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_438_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1563">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_439_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_439_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1562">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_440_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1561">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_441_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_441_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_441_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_441_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_441_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_441_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_441_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_441_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1560">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_442_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_442_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_442_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_442_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_442_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1559">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_443_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1558">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_444_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1557">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_445_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_445_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_445_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_445_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_445_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_445_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_445_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_445_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1556">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_446_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_446_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_446_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_446_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_446_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1555">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_447_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_447_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1554">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_448_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_448_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_448_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_448_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_448_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_448_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_448_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_448_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1553">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_449_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_449_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_449_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1552">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_450_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_450_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_450_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_450_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_450_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_450_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_450_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1551">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_451_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_451_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1550">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_452_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1549">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_453_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1548">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_454_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_454_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1547">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_455_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1546">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_456_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_456_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mm"
                 priority="1545">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_457_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr"
                 priority="1544">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_458_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1543">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_459_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1542">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_460_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1541">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_461_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1540">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_462_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1539">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_463_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1538">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_464_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1537">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_465_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1536">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_466_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1535">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_467_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1534">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_468_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1533">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_469_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1532">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_470_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1531">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_471_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1530">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_472_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1529">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_473_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1528">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_474_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1527">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_475_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1526">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_476_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1525">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_477_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1524">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_478_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1523">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_479_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1522">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_480_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1521">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_481_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1520">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_482_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1519">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_483_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1518">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_484_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1517">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_485_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1516">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_486_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1515">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_487_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1514">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_488_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1513">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_489_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1512">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_490_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1511">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_491_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1510">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_492_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1509">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_493_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1508">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_494_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1507">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_495_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1506">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_496_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1505">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_497_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1504">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_498_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1503">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_499_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1502">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_500_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1501">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_501_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1500">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_502_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1499">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_503_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1498">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_504_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1497">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_505_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1496">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_506_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1495">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_507_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1494">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_508_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1493">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_509_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1492">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_510_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1491">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_511_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1490">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_512_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1489">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_513_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1488">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_514_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1487">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_515_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1486">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_516_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1485">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_517_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1484">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_518_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1483">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_519_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1482">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_520_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1481">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_521_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1480">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_522_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1479">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_523_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1478">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_524_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1477">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_525_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1476">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_526_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1475">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_527_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1474">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_528_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]"
                 priority="1473">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_529_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L02.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_529_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L02.04 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_529_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_529_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L02.05 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_529_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L02.06 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_529_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L02.07 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1472">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L02.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L02.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L02.16 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L02.17 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_530_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_530_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_530_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_530_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_530_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1471">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_531_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_531_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1470">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_532_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_532_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_532_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_532_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_532_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1469">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_533_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_533_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1468">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_534_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1467">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_535_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1466">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_536_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1465">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_537_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_537_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_537_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_537_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_537_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_537_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_537_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_537_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1464">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_538_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_538_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1463">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_539_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1462">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_540_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_540_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_540_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_540_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_540_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1461">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_541_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1460">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_542_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_542_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_542_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_542_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_542_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_542_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_542_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1459">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_543_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_543_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1458">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_544_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_544_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_544_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_544_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_544_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_544_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_544_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_544_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1457">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_545_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_545_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1456">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_546_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1455">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_547_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_547_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_547_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_547_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_547_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1454">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_548_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1453">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_549_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1452">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_550_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_550_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_550_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_550_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_550_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1451">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_551_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_551_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1450">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_552_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_552_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_552_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_552_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_552_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_552_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_552_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_552_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1449">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_553_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_553_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_553_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1448">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_554_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_554_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_554_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_554_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_554_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_554_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_554_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1447">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_555_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_555_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1446">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_556_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1445">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_557_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1444">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_558_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_558_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1443">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_559_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1442">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_560_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_560_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mm"
                 priority="1441">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_561_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr"
                 priority="1440">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_562_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1439">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_563_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1438">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_564_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1437">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_565_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1436">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_566_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1435">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_567_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1434">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_568_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1433">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_569_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1432">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_570_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1431">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_571_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1430">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_572_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1429">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_573_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1428">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_574_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1427">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_575_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1426">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_576_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1425">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_577_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1424">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_578_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1423">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_579_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1422">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_580_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1421">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_581_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1420">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_582_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1419">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_583_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1418">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_584_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1417">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_585_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1416">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_586_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1415">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_587_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1414">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_588_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1413">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_589_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1412">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_590_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1411">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_591_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1410">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_592_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1409">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_593_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1408">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_594_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1407">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_595_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1406">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_596_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1405">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_597_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1404">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_598_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1403">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_599_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1402">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_600_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1401">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_601_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1400">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_602_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1399">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_603_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1398">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_604_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1397">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_605_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1396">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_606_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1395">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_607_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1394">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_608_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1393">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_609_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1392">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_610_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1391">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_611_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1390">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_612_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1389">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_613_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1388">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_614_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1387">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_615_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1386">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_616_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1385">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_617_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1384">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_618_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1383">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_619_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1382">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_620_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1381">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_621_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1380">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_622_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1379">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_623_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1378">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_624_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]"
                 priority="1377">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_625_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L05.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_625_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L05.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_625_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_625_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L05.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1376">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_626_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L05.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L05.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L05.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L05.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_626_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_626_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_626_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_626_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_626_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_626_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1375">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_627_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_627_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1374">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_628_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_628_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1373">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_629_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1372">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_630_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1371">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_631_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1370">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_632_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_632_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_632_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_632_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_632_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_632_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1369">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_633_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1368">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_634_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_634_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_634_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_634_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_634_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_634_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_634_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_634_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1367">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_635_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_635_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1366">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_636_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_636_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_636_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_636_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_636_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_636_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1365">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_637_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1364">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_638_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1363">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_639_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_639_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1362">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_640_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_640_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_640_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_640_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_640_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_640_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_640_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_640_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1361">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_641_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_641_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_641_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1360">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_642_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_642_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_642_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_642_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_642_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_642_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_642_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1359">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_643_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_643_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1358">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_644_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1357">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_645_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1356">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_646_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_646_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1355">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_647_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1354">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_648_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_648_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mm"
                 priority="1353">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_649_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr"
                 priority="1352">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_650_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1351">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_651_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1350">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_652_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1349">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_653_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1348">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_654_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1347">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_655_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1346">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_656_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1345">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_657_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1344">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_658_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1343">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_659_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1342">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_660_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1341">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_661_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1340">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_662_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1339">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_663_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1338">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_664_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1337">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_665_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1336">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_666_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1335">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_667_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1334">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_668_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1333">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_669_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1332">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_670_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1331">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_671_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1330">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_672_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1329">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_673_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1328">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_674_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1327">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_675_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1326">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_676_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1325">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_677_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1324">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_678_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1323">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_679_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1322">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_680_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1321">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_681_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1320">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_682_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1319">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_683_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1318">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_684_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1317">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_685_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1316">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_686_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1315">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_687_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1314">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_688_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1313">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_689_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1312">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_690_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1311">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_691_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1310">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_692_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1309">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_693_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1308">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_694_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1307">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_695_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1306">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_696_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]"
                 priority="1305">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_697_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L13.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_697_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L13.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_697_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_697_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L13.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1304">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L13.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L13.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L13.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L13.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_698_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_698_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_698_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1303">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_699_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_699_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1302">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_700_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1301">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_701_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1300">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_702_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1299">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_703_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1298">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_704_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_704_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_704_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_704_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_704_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_704_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1297">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_705_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1296">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_706_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_706_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1295">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_707_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_707_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1294">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_708_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_708_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_708_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_708_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_708_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_708_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1293">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_709_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1292">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_710_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1291">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_711_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_711_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1290">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_712_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_712_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_712_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_712_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1289">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_713_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_713_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_713_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1288">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_714_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_714_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_714_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_714_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1287">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_715_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_715_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1286">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_716_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1285">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_717_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1284">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_718_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_718_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1283">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_719_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1282">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_720_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_720_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mm"
                 priority="1281">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_721_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr"
                 priority="1280">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_722_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1279">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_723_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1278">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_724_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1277">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_725_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1276">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_726_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1275">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_727_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1274">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_728_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1273">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_729_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1272">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_730_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1271">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_731_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1270">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_732_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1269">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_733_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1268">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_734_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1267">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_735_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1266">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_736_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1265">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_737_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1264">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_738_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1263">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_739_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1262">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_740_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1261">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_741_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1260">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_742_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1259">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_743_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1258">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_744_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1257">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_745_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1256">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_746_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1255">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_747_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1254">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_748_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1253">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_749_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1252">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_750_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1251">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_751_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1250">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_752_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1249">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_753_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1248">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_754_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1247">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_755_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1246">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_756_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1245">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_757_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1244">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_758_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1243">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_759_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1242">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_760_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1241">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_761_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1240">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_762_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1239">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_763_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1238">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_764_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1237">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_765_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1236">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_766_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1235">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_767_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1234">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_768_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]"
                 priority="1233">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L09.10 (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3' or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">XGWA_OCCURS_769_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L09.10 (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L09.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_769_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_769_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L09.39 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1232">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NiederlassungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NiederlassungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_770_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">XGWA_OCCURS_770_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1231">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_771_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_771_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1230">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_772_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_772_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_772_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_772_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_772_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_772_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1229">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_773_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1228">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_774_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_774_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_774_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_774_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_774_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">XGWA_OCCURS_774_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1227">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_775_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_775_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1226">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_776_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_776_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_776_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_776_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_776_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_776_25</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1225">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_777_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1224">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_778_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1223">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_779_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_779_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1222">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_780_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_780_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_780_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_780_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1221">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_781_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_781_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_781_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1220">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_782_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_782_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_782_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_782_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1219">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_783_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1218">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_784_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1217">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_785_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_785_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mm"
                 priority="1216">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_786_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr"
                 priority="1215">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_787_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1214">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_788_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1213">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_789_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1212">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_790_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1211">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_791_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1210">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_792_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1209">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_793_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1208">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_794_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1207">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_795_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1206">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_796_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1205">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_797_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1204">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_798_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1203">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_799_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1202">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_800_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1201">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_801_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1200">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_802_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1199">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_803_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1198">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_804_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1197">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_805_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1196">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_806_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1195">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_807_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1194">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_808_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1193">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_809_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1192">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_810_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1191">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_811_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1190">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_812_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1189">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_813_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1188">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_814_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1187">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_815_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1186">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_816_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1185">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_817_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1184">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_818_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1183">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_819_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]"
                 priority="1182">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_820_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L04.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_820_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_820_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L04.04 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_820_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L04.05 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">XGWA_OCCURS_820_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L04.06 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_820_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L04.07 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1181">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L04.31 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L04.32 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L04.33 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L04.34 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_821_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_821_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_821_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_821_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_821_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1180">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_822_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_822_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1179">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_823_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_823_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_823_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_823_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_823_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_823_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_823_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_823_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1178">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_824_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1177">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_825_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1176">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_826_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1175">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_827_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_827_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_827_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_827_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_827_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_827_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1174">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_828_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_828_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1173">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_829_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_829_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_829_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_829_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_829_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_829_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_829_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_829_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1172">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_830_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_830_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_830_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_830_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_830_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_830_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_830_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1171">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_831_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_831_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1170">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_832_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_832_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_832_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_832_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_832_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_23</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">XGWA_OCCURS_832_24</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1169">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_833_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_833_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1168">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_834_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_834_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_834_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_834_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_834_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_834_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_834_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_834_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1167">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_835_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1166">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_836_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_836_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_836_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_836_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_836_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_836_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_836_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_836_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1165">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_837_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_837_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1164">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_838_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_838_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_838_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_838_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_838_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_838_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_838_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_838_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1163">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_839_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_839_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_839_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1162">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_840_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_840_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_840_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_840_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_840_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_840_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_840_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1161">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">XGWA_OCCURS_841_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_841_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1160">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_842_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1159">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_843_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1158">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">XGWA_OCCURS_844_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_844_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1157">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_845_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1156">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_846_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_846_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mm"
                 priority="1155">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_847_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr"
                 priority="1154">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_848_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1153">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_849_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1152">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_850_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1151">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_851_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1150">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_852_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1149">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_853_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1148">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_854_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1147">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_855_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1146">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_856_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1145">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_857_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1144">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_858_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1143">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_859_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1142">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_860_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1141">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_861_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1140">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_862_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1139">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_863_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1138">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_864_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1137">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_865_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1136">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_866_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1135">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_867_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1134">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_868_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1133">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_869_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1132">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_870_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1131">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_871_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_872_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_873_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_874_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_875_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_876_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_877_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_878_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_879_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_880_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_881_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_882_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_883_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_884_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_885_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_886_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_887_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_888_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_889_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_890_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_891_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_892_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_893_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_894_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_895_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_896_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_897_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_898_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_899_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_900_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]"
                 priority="1101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">XGWA_OCCURS_901_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L10.04 (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">XGWA_OCCURS_901_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L10.04 (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_901_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L10.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_901_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L10.12 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FKSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FKSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FKSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_901_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">XGWA_OCCURS_902_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">XGWA_OCCURS_902_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_902_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">XGWA_OCCURS_902_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">XGWA_OCCURS_902_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">XGWA_OCCURS_902_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung L10.11 (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">XGWA_OCCURS_902_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung L10.11 (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_903_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_903_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_904_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_904_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_904_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_904_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_904_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_904_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_904_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_904_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_905_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_905_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_905_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_905_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_905_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_906_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_906_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_907_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_908_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_909_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_910_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_910_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_910_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_910_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_910_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_910_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_910_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_911_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_911_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_912_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_913_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_913_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_913_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_913_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_913_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_913_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_913_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_913_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_914_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_914_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_914_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_914_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_914_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_915_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_916_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_916_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_916_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_916_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">XGWA_OCCURS_916_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_916_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_917_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_917_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_918_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_918_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_918_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_918_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">XGWA_OCCURS_918_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_918_21</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">XGWA_OCCURS_918_22</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_919_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_920_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_921_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_921_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_922_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_923_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_924_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_925_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">XGWA_OCCURS_925_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">XGWA_OCCURS_925_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_925_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_925_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">XGWA_OCCURS_925_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_925_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_925_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_926_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_927_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">XGWA_OCCURS_927_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_928_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_928_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_928_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_928_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_928_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_928_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_928_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_928_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">XGWA_OCCURS_929_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_929_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">XGWA_OCCURS_929_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">XGWA_OCCURS_930_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_930_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_930_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">XGWA_OCCURS_930_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_931_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_03</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_04</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_05</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_06</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_07</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_08</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_09</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_11</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_12</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_13</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_15</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_16</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_17</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_18</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_19</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_932_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">XGWA_OCCURS_933_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">XGWA_OCCURS_934_02</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mm"
                 priority="1067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText')">
               <xsl:attribute name="id">XGWA_OCCURS_935_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr"
                 priority="1066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">XGWA_OCCURS_936_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">XGWA_OCCURS_937_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">XGWA_OCCURS_938_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_939_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_940_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_941_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_942_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_943_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_944_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">XGWA_OCCURS_945_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_946_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_947_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_948_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_949_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_950_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_951_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_952_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_953_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_954_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_955_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_956_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_957_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_958_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_959_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_960_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_961_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_962_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_963_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_964_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">XGWA_OCCURS_965_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">XGWA_OCCURS_966_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_967_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_968_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">XGWA_OCCURS_969_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">XGWA_OCCURS_970_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_971_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_972_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_973_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_974_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_975_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_976_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_977_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_978_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">XGWA_OCCURS_979_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_980_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_981_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_982_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">XGWA_OCCURS_983_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_984_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">XGWA_OCCURS_985_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_986_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_987_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">XGWA_OCCURS_988_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_989_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_990_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">XGWA_OCCURS_991_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_992_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">XGWA_OCCURS_993_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_994_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">XGWA_OCCURS_995_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">XGWA_OCCURS_996_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">XGWA_OCCURS_997_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_998_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">XGWA_OCCURS_999_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1000_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">XGWA_OCCURS_1001_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">XGWA_OCCURS_1002_01</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M7" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
</xsl:stylesheet>
